-- lua/gemini/init.lua

local api = require("gemini.api")
local chat = require("gemini.chat")
local config = require("gemini.config")

local M = {}

local function get_current_buffer_content()
    local lines = vim.api.nvim_buf_get_lines(0, 0, -1, false)
    return table.concat(lines, "\n")
end

function M.prompt_query(context)
    local prompt = context and "Gemini (with buffer context): " or "Gemini: "
    vim.ui.input({ prompt = prompt }, function(input)
        if input then
            M.query(input, context)
        end
    end)
end

function M.query(prompt, context)
    chat.set_context(context)
    chat.create_window()
    
    local initial_content = "User: " .. prompt .. "\n\nAssistant: Thinking..."
    chat.update_content(initial_content, true)
    vim.cmd('redraw')
    
    api.get_response(prompt, context, function(response, error)
        if error then
            vim.notify("Failed to get response: " .. error, vim.log.levels.ERROR)
            return
        end

        local content = "User: " .. prompt .. "\n\nAssistant: " .. response
        chat.update_content(content, true)
    end)
end

function M.setup(opts)
    -- Configure the plugin
    config.setup(opts)

    -- Ensure markdown parser is installed
    pcall(vim.treesitter.language.require_language, "markdown")

    -- Create commands
    vim.api.nvim_create_user_command("Gemini", function(opts)
        if opts.args == "" then
            vim.notify("Please provide a prompt for Gemini.", vim.log.levels.WARN)
            return
        end
        M.query(opts.args)
    end, {
        desc = "Query Google AI",
        nargs = "+",
        complete = "shellcmd",
    })

    vim.api.nvim_create_user_command("GeminiClearChat", function()
        api.clear_conversation()
        chat.clear()
        vim.notify("Chat history cleared", vim.log.levels.INFO)
    end, {
        desc = "Clear Gemini chat history"
    })

    -- Set up default keymaps
    vim.keymap.set("n", "<leader>gc", function()
        M.prompt_query()
    end, { desc = "Chat with Gemini AI" })

    vim.keymap.set("n", "<leader>gs", function()
        M.prompt_query(get_current_buffer_content())
    end, { desc = "Chat with Gemini AI (with buffer context)" })

    vim.keymap.set("n", "<leader>gq", function()
        api.clear_conversation()
        chat.clear()
        vim.notify("Chat history cleared", vim.log.levels.INFO)
    end, { desc = "Clear Gemini chat history" })
end

return M
